::: beignet.datasets.CarbonMangelsCytochromeP4502C9SubstrateDataset
::: beignet.datasets.CarbonMangelsCytochromeP4502D6SubstrateDataset
::: beignet.datasets.CarbonMangelsCytochromeP4503A4SubstrateDataset
::: beignet.datasets.VeithCytochromeP4501A2InhibitionDataset
::: beignet.datasets.VeithCytochromeP4502C19InhibitionDataset
::: beignet.datasets.VeithCytochromeP4502C9InhibitionDataset
::: beignet.datasets.VeithCytochromeP4502D6InhibitionDataset
::: beignet.datasets.VeithCytochromeP4503A4InhibitionDataset